mathics: General-purpose computer algebra system
================================================

Description
-----------

General-purpose computer algebra system

License
-------

GPL

Upstream Contact
----------------

https://pypi.org/project/Mathics3/

